pub struct ReflectAddAssign {
pub add_assign: fn(&mut dyn Reflect, Box<dyn PartialReflect>) -> Result<(), Option<Box<dyn PartialReflect>>>,
}Expand description
A struct used to perform addition assignment on reflected values.
A ReflectAddAssign for type T can be obtained via FromType::from_type.
Fields
add_assign: fn(&mut dyn Reflect, Box<dyn PartialReflect>) -> Result<(), Option<Box<dyn PartialReflect>>>Function pointer implementing ReflectAddAssign::add_assign().
Implementations
Sourceimpl ReflectAddAssign
impl ReflectAddAssign
Sourcepub fn add_assign(
&self,
a: &mut dyn Reflect,
b: Box<dyn PartialReflect>,
) -> Result<(), Option<Box<dyn PartialReflect>>>
pub fn add_assign( &self, a: &mut dyn Reflect, b: Box<dyn PartialReflect>, ) -> Result<(), Option<Box<dyn PartialReflect>>>
Adds a reflected value to another reflected value in place.
Errors
- Returns
Err(None)if the first argument is of an incompatible type. - Returns
Err(Some(b))if the second argument is of an incompatible type.