pub struct ReflectDivAssign {
pub div_assign: fn(&mut dyn Reflect, Box<dyn PartialReflect>) -> Result<(), Option<Box<dyn PartialReflect>>>,
}Expand description
A struct used to perform division assignment on reflected values.
A ReflectDivAssign for type T can be obtained via FromType::from_type.
Fields
div_assign: fn(&mut dyn Reflect, Box<dyn PartialReflect>) -> Result<(), Option<Box<dyn PartialReflect>>>Function pointer implementing ReflectDivAssign::div_assign().
Implementations
Sourceimpl ReflectDivAssign
impl ReflectDivAssign
Sourcepub fn div_assign(
&self,
a: &mut dyn Reflect,
b: Box<dyn PartialReflect>,
) -> Result<(), Option<Box<dyn PartialReflect>>>
pub fn div_assign( &self, a: &mut dyn Reflect, b: Box<dyn PartialReflect>, ) -> Result<(), Option<Box<dyn PartialReflect>>>
Divides a reflected value by another reflected value in place.
Errors
- Returns
Err(None)if the first argument is of an incompatible type. - Returns
Err(Some(b))if the second argument is of an incompatible type.