pub struct ReflectRem {
pub rem: fn(Box<dyn PartialReflect>, Box<dyn PartialReflect>) -> Result<Box<dyn Reflect>, (Box<dyn PartialReflect>, Box<dyn PartialReflect>)>,
}Expand description
A struct used to perform remainder on reflected values.
A ReflectRem for type T can be obtained via FromType::from_type.
Fields
rem: fn(Box<dyn PartialReflect>, Box<dyn PartialReflect>) -> Result<Box<dyn Reflect>, (Box<dyn PartialReflect>, Box<dyn PartialReflect>)>Function pointer implementing ReflectRem::rem().
Implementations
Sourceimpl ReflectRem
impl ReflectRem
Sourcepub fn rem(
&self,
a: Box<dyn PartialReflect>,
b: Box<dyn PartialReflect>,
) -> Result<Box<dyn Reflect>, (Box<dyn PartialReflect>, Box<dyn PartialReflect>)>
pub fn rem( &self, a: Box<dyn PartialReflect>, b: Box<dyn PartialReflect>, ) -> Result<Box<dyn Reflect>, (Box<dyn PartialReflect>, Box<dyn PartialReflect>)>
Computes the remainder of two reflected values, returning the result as a new reflected value.
Errors
Returns Err((a, b)) if the types are incompatible.