pub struct ReflectAdd {
pub add: fn(Box<dyn PartialReflect>, Box<dyn PartialReflect>) -> Result<Box<dyn Reflect>, (Box<dyn PartialReflect>, Box<dyn PartialReflect>)>,
}Expand description
A struct used to perform addition on reflected values.
A ReflectAdd for type T can be obtained via FromType::from_type.
Fields
add: fn(Box<dyn PartialReflect>, Box<dyn PartialReflect>) -> Result<Box<dyn Reflect>, (Box<dyn PartialReflect>, Box<dyn PartialReflect>)>Function pointer implementing ReflectAdd::add().
Implementations
Sourceimpl ReflectAdd
impl ReflectAdd
Sourcepub fn add(
&self,
a: Box<dyn PartialReflect>,
b: Box<dyn PartialReflect>,
) -> Result<Box<dyn Reflect>, (Box<dyn PartialReflect>, Box<dyn PartialReflect>)>
pub fn add( &self, a: Box<dyn PartialReflect>, b: Box<dyn PartialReflect>, ) -> Result<Box<dyn Reflect>, (Box<dyn PartialReflect>, Box<dyn PartialReflect>)>
Adds two reflected values together, returning the result as a new reflected value.
Errors
Returns Err((a, b)) if the types are incompatible.