pub struct ReflectDiv {
pub div: fn(Box<dyn PartialReflect>, Box<dyn PartialReflect>) -> Result<Box<dyn Reflect>, (Box<dyn PartialReflect>, Box<dyn PartialReflect>)>,
}Expand description
A struct used to perform division on reflected values.
A ReflectDiv for type T can be obtained via FromType::from_type.
Fields
div: fn(Box<dyn PartialReflect>, Box<dyn PartialReflect>) -> Result<Box<dyn Reflect>, (Box<dyn PartialReflect>, Box<dyn PartialReflect>)>Function pointer implementing ReflectDiv::div().
Implementations
Sourceimpl ReflectDiv
impl ReflectDiv
Sourcepub fn div(
&self,
a: Box<dyn PartialReflect>,
b: Box<dyn PartialReflect>,
) -> Result<Box<dyn Reflect>, (Box<dyn PartialReflect>, Box<dyn PartialReflect>)>
pub fn div( &self, a: Box<dyn PartialReflect>, b: Box<dyn PartialReflect>, ) -> Result<Box<dyn Reflect>, (Box<dyn PartialReflect>, Box<dyn PartialReflect>)>
Divides two reflected values, returning the result as a new reflected value.
Errors
Returns Err((a, b)) if the types are incompatible.